@@ -1,9 +1,11 @@
+from typing import Any, Iterator
+
 import psycopg2
 import psycopg2.extras
 
 
 class Database(object):
-    def __init__(self, user: str, password: str, database: str, host: str = 'localhost', port=5432):
+    def __init__(self, user: str, password: str, database: str, host: str = 'localhost', port: int = 5432):
         self._con = psycopg2.connect(
             host=host,
             port=port,
@@ -25,14 +27,14 @@ class Database(object):
             self._con.rollback()
             raise e
 
-    def perform(self, sql: str, *args: any) -> int:
+    def perform(self, sql: str, *args: Any) -> int:
         with self._con.cursor() as cur:
             self._execute(cur, sql, args)
             self._con.commit()
 
             return cur.rowcount
 
-    def select(self, sql: str, *args: any) -> iter:
+    def select(self, sql: str, *args: Any) -> Iterator[dict]:
         with self._con.cursor(cursor_factory=psycopg2.extras.RealDictCursor) as cur:
             self._execute(cur, sql, args)
             self._con.commit()
@@ -41,14 +43,14 @@ class Database(object):
         for row in rows:
             yield dict(row)
 
-    def procedure(self, func_name: str, **parameters: any) -> int:
+    def procedure(self, func_name: str, **parameters: Any) -> int:
         with self._con.cursor() as cur:
             self._callproc(cur, func_name, parameters)
             self._con.commit()
 
             return cur.rowcount
 
-    def function(self, func_name: str, **parameters: any) -> iter:
+    def function(self, func_name: str, **parameters: Any) -> Iterator[dict]:
         with self._con.cursor(cursor_factory=psycopg2.extras.RealDictCursor) as cur:
             self._callproc(cur, func_name, parameters)
             self._con.commit()
